# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: hotels.proto
# Protobuf Python Version: 5.29.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    3,
    '',
    'hotels.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0chotels.proto\x12\x0b\x66\x61st_hotels\"?\n\x08Location\x12\x0c\n\x04\x63ity\x18\x01 \x01(\t\x12\x0f\n\x07\x63ountry\x18\x02 \x01(\t\x12\x14\n\x0c\x61irport_code\x18\x03 \x01(\t\"\x9a\x01\n\tHotelData\x12\x14\n\x0c\x63heckin_date\x18\x01 \x01(\t\x12\x15\n\rcheckout_date\x18\x02 \x01(\t\x12\'\n\x08location\x18\x03 \x01(\x0b\x32\x15.fast_hotels.Location\x12\x16\n\troom_type\x18\x04 \x01(\tH\x00\x88\x01\x01\x12\x11\n\tamenities\x18\x05 \x03(\tB\x0c\n\n_room_type\"0\n\x06Guests\x12&\n\x06guests\x18\x01 \x03(\x0e\x32\x16.fast_hotels.GuestType\"\x8e\x01\n\x04Info\x12$\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x16.fast_hotels.HotelData\x12(\n\troom_type\x18\x02 \x01(\x0e\x32\x15.fast_hotels.RoomType\x12#\n\x06guests\x18\x03 \x01(\x0b\x32\x13.fast_hotels.Guests\x12\x11\n\tamenities\x18\x05 \x03(\t*P\n\x08RoomType\x12\x10\n\x0cUNKNOWN_ROOM\x10\x00\x12\x0c\n\x08STANDARD\x10\x01\x12\n\n\x06\x44\x45LUXE\x10\x02\x12\t\n\x05SUITE\x10\x03\x12\r\n\tEXECUTIVE\x10\x04*@\n\tGuestType\x12\x11\n\rUNKNOWN_GUEST\x10\x00\x12\t\n\x05\x41\x44ULT\x10\x01\x12\t\n\x05\x43HILD\x10\x02\x12\n\n\x06INFANT\x10\x03\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'hotels_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_ROOMTYPE']._serialized_start=446
  _globals['_ROOMTYPE']._serialized_end=526
  _globals['_GUESTTYPE']._serialized_start=528
  _globals['_GUESTTYPE']._serialized_end=592
  _globals['_LOCATION']._serialized_start=29
  _globals['_LOCATION']._serialized_end=92
  _globals['_HOTELDATA']._serialized_start=95
  _globals['_HOTELDATA']._serialized_end=249
  _globals['_GUESTS']._serialized_start=251
  _globals['_GUESTS']._serialized_end=299
  _globals['_INFO']._serialized_start=302
  _globals['_INFO']._serialized_end=444
# @@protoc_insertion_point(module_scope)
